# black-isort-hook

A simple pre-commit hook to run black and isort on staged files

## Installation

With pip

```bash
pip install black-isort-hook
```

With poetry 

```bash
poetry add black-isort-hook
```

## Usage

In your git repository

```bash
install-black-isort-hook
```
